@@ -218,40 +218,6 @@ def _tree():
     return defaultdict(_tree)
 
 
-def _fetch_documentation(version, base_url="https://spark.apache.org/docs"):
-    import pandas as pd
-    doc_urls = [
-        "{base_url}/{version}/configuration.html",
-        "{base_url}/{version}/sql-programming-guide.html",
-        "{base_url}/{version}/monitoring.html",
-        "{base_url}/{version}/spark-standalone.html",
-        "{base_url}/{version}/running-on-mesos.html",
-        "{base_url}/{version}/running-on-yarn.html",
-    ]
-
-    for url in doc_urls:
-        doc_url = url.format(version=version, base_url=base_url)
-        print(url)
-        log.debug("Loading spark properties from %s", doc_url)
-        dfs = pd.read_html(doc_url, header=0)
-        for df in dfs:
-            if ("Property Name" in df) and ('Default' in df):
-                for pn, default, desc in df[["Property Name", "Default", "Meaning"]].itertuples(index=False):
-                    yield pn, default, desc
-
-
-def _save_documentation(version, base_url="https://spark.apache.org/docs", target_dir=None):
-    """Write the spark property documentation to a file
-    """
-    if target_dir is None:
-        target_dir = os.path.dirname(__file__)
-    with open(os.path.join(target_dir, "spark_properties_{}.json".format(version)), 'w') as fp:
-        all_props = _fetch_documentation(version=version, base_url=base_url)
-        all_props = sorted(all_props, key=lambda x: x[0])
-        all_props_d = [{"property": p, "default": d, "description": desc} for p, d, desc in all_props]
-        json.dump(all_props_d, fp, indent=2)
-
-
 class _SparkConfHelper(object):
 
     def __init__(self, version='latest', existing_conf=None):
@@ -401,8 +367,12 @@ class SparkConfiguration(object):
         p.end_group(1, ')')
 
     def __init__(self, python_path=None, spark_conf=None, spark_launcher_args=None):
-        self._spark_launcher_args = spark_launcher_args or self._default_spark_launcher_args
-        self._python_path = python_path or "python"
+        if spark_launcher_args is None:
+            spark_launcher_args = SparkConfiguration._default_spark_launcher_args.copy()
+        self._spark_launcher_args = spark_launcher_args
+        if python_path is None:
+            python_path = "python"
+        self._python_path = python_path
         self._spark_home = None
         self._spark_conf_helper = _SparkConfHelper(existing_conf=spark_conf or self._default_spark_conf)
 
@@ -420,7 +390,8 @@ class SparkConfiguration(object):
         spark_arg = key.replace('_', '-')
         if key.startswith("_"):
             return super(SparkConfiguration, self).__setattr__(key, value)
-
+        if spark_arg not in self._spark_launcher_arg_names:
+            raise AttributeError('%s object has no attribute %s' % (self.__class__.__name__, key))
         if spark_arg in self._spark_launcher_arg_names:
             self._spark_launcher_args[spark_arg] = value
 
@@ -429,8 +400,9 @@ class SparkConfiguration(object):
         if key.startswith("_"):
             return super(SparkConfiguration, self).__getattribute__(key)
         spark_arg = key.replace('_', '-')
-        if spark_arg in self._spark_launcher_arg_names:
-            return self._spark_launcher_args.get(spark_arg)
+        if spark_arg not in self._spark_launcher_arg_names:
+            raise AttributeError('%s object has no attribute %s' % (self.__class__.__name__, key))
+        return self._spark_launcher_args.get(spark_arg)
 
     def __setitem__(self, key, val):
         return self._spark_conf.__setitem__(key, val)
